####################
Django Google Mailer
####################

Django Google Mailer is a Django app which is an alternative to send emails
using Google's Gmail API. This is the most secure method as it uses OAuth 2.0.

Detailed documentation is in the "docs" directory.

Contents
^^^^^^^^

.. toctree::
  :maxdepth: 3
  :hidden:

  Home <self>

.. toctree::

  quick-start
  Reference <modules>

.. toctree::
  :hidden:

  Versions <change>
  genindex


Google Privacy Policies
=======================

- `Google APIs Terms of Service <https://developers.google.com/terms>`_
- `Google API Services User Data Policy <https://developers.google.com/terms/api-services-user-data-policy>`_

LICENSE
=======

.. include:: ../LICENSE

.. meta::
  :description: Django Google Mailer is a Django app which is an alternative to send emails using Google's Gmail API. This is the most secure method as it uses OAuth 2.0.
  :keywords: django, google, gmail, api, python package
